@@ -13,7 +13,7 @@
 
 namespace torch::autograd {
 
-struct TORCH_CUDA_CU_API Scatter : public Node {
+struct TORCH_HIP_API Scatter : public Node {
   explicit Scatter(
       std::vector<at::Device> devices,
       std::optional<std::vector<int64_t>> chunk_sizes = std::nullopt,
@@ -32,7 +32,7 @@ struct TORCH_CUDA_CU_API Scatter : public Node {
   bool unsqueeze_scalars_;
 };
 
-struct TORCH_CUDA_CU_API Gather : public Node {
+struct TORCH_HIP_API Gather : public Node {
   explicit Gather(const at::Device& destination_device, int64_t dim = 0);
   ~Gather() override;
 
